==> stop_admin-8.x-1.3.tar.gz: stop_admin/tests/src/Functional/StopAdminUserLoginPageTest.php <==
<?php

namespace Drupal\Tests\stop_admin\Functional;

use Drupal\Tests\BrowserTestBase;

/**
 * Defines tests for StopAdminUserLoginPage.
 *
 * @package Drupal\Tests\stop_admin\Functional
 * @group stop_admin
 */
class StopAdminUserLoginPageTest extends BrowserTestBase {

  /**
   * Modules to enable.
   *
   * @var array
   */
  public static $modules = ['stop_admin'];

  /**
   * A non-administrator user for this test.
   *
   * @var \Drupal\user\UserInterface
   */
  protected $regularUser;

  /**
   * {@inheritdoc}
   */
  protected $defaultTheme = 'stark';

  /**
   * {@inheritdoc}
   */
  protected function setUp() {
    parent::setUp();
    // Create a regular user and activate it.
    $this->regularUser = $this->createUser();
    $this->drupalLogin($this->regularUser);
    $this->drupalLogout();
  }

  /**
   * Test the user login page as user 1.
   */
  public function testUserLoginPageUserOne() {
    $this->drupalGet('user/login');
    $edit = [
      'name' => $this->rootUser->getAccountName(),
      'pass' => $this->rootUser->passRaw,
    ];
    $this->submitForm($edit, 'Log in');
    $this->assertTrue(strpos($this->getSession()->getPage()->getContent(), (string) 'Log in') > 0, 'User is not logged in.');
    $this->assertSession()->pageTextContains('Unrecognized username or password. Forgot your password?', 'Error message appeared.');
  }

  /**
   * Test the user login page as an authenticated user.
   */
  public function testUserLoginPageUserAuthenticated() {

    $this->drupalGet('user/login');
    $edit = [
      'name' => $this->regularUser->getAccountName(),
      'pass' => $this->regularUser->passRaw,
    ];
    $this->submitForm($edit, 'Log in');
    $this->assertFalse(strpos($this->getSession()->getPage()->getContent(), (string) 'Log in') > 0, 'User is logged in.');
    $this->assertSession()->pageTextNotContains('Unrecognized username or password. Forgot your password?', 'Error message did not appear.');
  }

  /**
   * Test the user login page as user 1 when the setting is set to disabled.
   */
  public function testStopAdminDisabledUserLoginPageUserOne() {
    // Disable the setting.
    \Drupal::configFactory()
      ->getEditable('stop_admin.settings')
      ->set('disabled', TRUE)
      ->save(TRUE);
    // Test to make sure we can login as user 1.
    $edit = [
      'name' => $this->rootUser->getAccountName(),
      'pass' => $this->rootUser->passRaw,
    ];
    $this->submitForm($edit, 'Log in');
    $this->assertFalse(strpos($this->getSession()->getPage()->getContent(), (string) 'Log in') > 0, 'User is logged in.');
    $this->assertSession()->pageTextNotContains('Unrecognized username or password. Forgot your password?', 'Error message did not appear.');
  }

}

==> stop_admin-8.x-1.4.tar.gz: stop_admin/tests/src/Functional/StopAdminUserLoginPageTest.php <==
<?php

namespace Drupal\Tests\stop_admin\Functional;

use Drupal\Tests\BrowserTestBase;

/**
 * Defines tests for StopAdminUserLoginPage.
 *
 * @package Drupal\Tests\stop_admin\Functional
 * @group stop_admin
 */
class StopAdminUserLoginPageTest extends BrowserTestBase {

  /**
   * Modules to enable.
   *
   * @var array
   */
  protected static $modules = ['stop_admin'];

  /**
   * A non-administrator user for this test.
   *
   * @var \Drupal\user\UserInterface
   */
  protected $regularUser;

   /**
   * A administrator user for this test.
   *
   * @var \Drupal\user\UserInterface
   */
  protected $adminUser;

  /**
   * {@inheritdoc}
   */
  protected $defaultTheme = 'stark';

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    parent::setUp();
    // Create a regular user and activate it.
    $this->regularUser = $this->createUser();
    $this->drupalLogin($this->regularUser);
    $this->drupalLogout();

    // Create a administrator user and activate it.
    $this->adminUser = $this->createUser([], 'superadmin', TRUE);
    $this->drupalLogin($this->adminUser);
    $this->drupalLogout();
  }

  /**
   * Test the user login page as user 1.
   */
  public function testUserLoginPageUserOne() {
    $this->drupalGet('user/login');
    $edit = [
      'name' => $this->rootUser->getAccountName(),
      'pass' => $this->rootUser->passRaw,
    ];
    $this->submitForm($edit, 'Log in');
    $this->assertTrue(strpos($this->getSession()->getPage()->getContent(), (string) 'Log in') > 0, 'User is not logged in.');
    $this->assertSession()->pageTextContains('Unrecognized username or password. Forgot your password?', 'Error message appeared.');
  }

  /**
   * Test the user login page as an authenticated user.
   */
  public function testUserLoginPageUserAuthenticated() {
    $this->drupalGet('user/login');
    $edit = [
      'name' => $this->regularUser->getAccountName(),
      'pass' => $this->regularUser->passRaw,
    ];
    $this->submitForm($edit, 'Log in');
    $this->assertFalse(strpos($this->getSession()->getPage()->getContent(), (string) 'Log in') > 0, 'User is logged in.');
    $this->assertSession()->pageTextNotContains('Unrecognized username or password. Forgot your password?', 'Error message did not appear.');
  }

  /**
   * Test the user login page as user 1 when the setting is set to disabled.
   */
  public function testStopAdminDisabledUserLoginPageUserOne() {
    // Disable the setting.
    \Drupal::configFactory()
      ->getEditable('stop_admin.settings')
      ->set('disabled', TRUE)
      ->save(TRUE);

    $this->drupalGet('user/login');
    $edit = [
      'name' => $this->rootUser->getAccountName(),
      'pass' => $this->rootUser->passRaw,
    ];
    $this->submitForm($edit, 'Log in');
    $this->assertFalse(strpos($this->getSession()->getPage()->getContent(), (string) 'Log in') > 0, 'User is logged in.');
    $this->assertSession()->pageTextNotContains('Unrecognized username or password. Forgot your password?', 'Error message did not appear.');
  }

  /**
   * Test that without the setting enabled admin users can sign in.
   */
  public function testStopAdminRoleSettingDisabledAdminUser() {
    $this->drupalGet('user/login');
    $edit = [
      'name' => $this->adminUser->getAccountName(),
      'pass' => $this->adminUser->passRaw,
    ];
    $this->submitForm($edit, 'Log in');
    $this->assertFalse(strpos($this->getSession()->getPage()->getContent(), (string) 'Log in') > 0, 'User is logged in.');
    $this->assertSession()->pageTextNotContains('Unrecognized username or password. Forgot your password?', 'Error message did not appear.');
  }

  /**
   * Test with the setting enabled admin users can no longer sign in.
   */
  public function testStopAdminRoleSettingEnabledAdminUser() {
    \Drupal::configFactory()
      ->getEditable('stop_admin.settings')
      ->set('block_admin_role', TRUE)
      ->save(TRUE);

    $this->drupalGet('user/login');
    $edit = [
      'name' => $this->adminUser->getAccountName(),
      'pass' => $this->adminUser->passRaw,
    ];
    $this->submitForm($edit, 'Log in');
    $this->assertTrue(strpos($this->getSession()->getPage()->getContent(), (string) 'Log in') > 0, 'User is not logged in.');
    $this->assertSession()->pageTextContains('Unrecognized username or password. Forgot your password?', 'Error message appeared.');
  }

}
